﻿Fluke Corporation                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub AT MSO/DSO60xx (1 yr) Bandwidth IEEE /9500
INSTRUMENT:            Sub AT MSO/DSO6xxx (1 yr) Horiz Delta t IEEE /9500
INSTRUMENT:            Sub AT MSO/DSO60xx (1 yr) Trig Sens IEEE /9500
INSTRUMENT:            Sub AT MSO/DSO60x2 (1 yr) Ext Trig 2Ch IEEE /9500
INSTRUMENT:            Sub AT MSO/DSO60xx (1 yr) Time Scale IEEE /9500
DATE:                  2011-02-09 07:28:26
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       18
NUMBER OF LINES:       593
CONFIGURATION:         Datron 9500 (S6)
CONFIGURATION:         Datron 9510 on channel 1
=============================================================================
#
#  Procedure Author:
#        GCM, DFM, ZY, DAC, CAD
#
#  Model(s) Covered:
#        Agilent MSO/DSO 6000 Series: MSO/DSO6012A, MSO/DSO6032A,
#         MSO/DSO6052A, MSO/DSO6014A, MSO/DSO6034A, MSO/DSO6054A
#
#  Compatibility:
#        MET/CAL 7.3 or later
#
#  Subprocedures:
#        Sub AT MSO/DSO6xxx Select Channel
#        Sub AT MSO/DSO6xxx Wait for Triggered
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        Agilent 11667A Power Splitter (for external trigger tests)
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Select external trigger procedure based on whether UUT is 2 or 4 channel.
#    2 channel scopes have a front panel EXT TRIG IN.
#    4 channel scopes have a rear panel AUX TRIG IN.
#    The two variations have different specifications and test methodologies.
#
#  Two different schemes are used to verify UUT external trigger, depending
#  on whether the 9500 used has a single or multiple active heads. In the
#  case of a single active head system, a power splitter is required to
#  provide a simultaneous trigger signal.
#
#  9500, multiple active heads:
#  In the subsequent external trigger tests, the 9500 dual leveled sine mode
#  is used to supply an identical signal level simultaneously to the vertical
#  and external trigger inputs.
#
#  9500, single active head:
#  In the subsequent external trigger tests, a power splitter is used to
#  supply an identical signal level simultaneously to the vertical and
#  external trigger inputs. Because the power splitter output is 6 dB lower
#  (½ the voltage input) than the input, the 58xxA output is initially set to
#  twice the desired level at the vertical and AUX TRIG IN inputs. The output
#  is then adjusted until the desired value is measured at the UUT vertical
#  input.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  CALL         Sub AT MSO/DSO6xxx Select Channel

  1.002  JMPL         BANDWIDTH                    PSUBI("Bandwidth")
  1.003  JMPL         HORIZ_DELTA                  PSUBI("Horiz Delta")
  1.004  JMPL         TRIGGER                      PSUBI("Trig Sens")
  1.005  JMPL         EXT_TRIG_2CH                 PSUBI("Ext Trig 2Ch")
  1.006  JMPL         TIME_SCALE                   PSUBI("Time Scale")

  1.007  DISP         {Undefined subprocedure!}

  1.008  END

  1.009  EVAL   Increment step number


# Sub AT MSO/DSO60xx (1 yr) Bandwidth IEEE /9500 =============================

  2.001  LABEL        BANDWIDTH

# If TAR mode is selected, set NTHROW to zero to reduce execution time.
  2.002  IF           ZCMPI(@MeasMode, "TAR")
  2.003  TSET         NTHROW = 0
  2.004  ENDIF

  2.005  IF           @Chan == 1
  2.006  RSLT         =
  2.007  HEAD         VERTICAL {BANDWIDTH (-3 dB)}
  2.008  RSLT         =
  2.009  ELSE
  2.010  HEAD         VERTICAL BANDWIDTH (-3 dB)
  2.011  ENDIF

  2.012  HEAD         -2 Channel [V @Chan]: 200 mV/div
  2.013  MATH         Freq = @Bandwidth / 1E+6
  2.014  TARGET       -p

  2.015  SCPI         ACQ:MODE ETIME;TYPE AVERAGE;COUNT 8
  2.016  SCPI         TRIG:MODE EDGE;SWE AUTO;SOUR CHAN[V @Chan]
  2.017  SCPI         MEAS:SOURCE CHAN[V @Chan]
  2.018  SCPI         CHAN[V @Chan]:SCAL 200mV;COUP DC

  2.019  IF           @Bandwidth > 100E+6
  2.020  SCPI         CHAN[V @Chan]:IMP FIFT
  2.021  ENDIF

  2.022  TARGET       -m
  2.023  SCPI         TIM:SCAL 500ns
  2.024  MATH         MEM = 1200; MEM1 = MEM

# Set the output of the calibrator so the peak-to-peak measurement is
# between 1198 and 1202 mV.
  2.025  DO
  2.026  MATH         MEM = MEM1 + (1200 - MEM) / 2

  2.027  IF           @Bandwidth == 100E+6
  2.028  9500         mVpp                         1MH            LS    S
  2.029  ELSE
  2.030  9500         mVpp                         1MH            LS    S  L
  2.031  ENDIF

  2.032  WAIT         [D1000]
  2.033  SCPI         MEAS:VAMP?[I]
  2.034  MATH         MEM = MEM / 1E-3
  2.035  UNTIL        (MEM >= 1198) && (MEM <= 1202)

# Store UUT amplitude reading at reference frequency in L[1].
  2.036  MATH         L[1] = MEM
# Copy last calibrator amplitude setting (in MEM1) to MEM to set 58xxA output.
  2.037  MATH         MEM = MEM1

  2.038  IF           @Bandwidth == 100E+6
  2.039  SCPI         TIM:SCAL 5ns
  2.040  9500         mVpp                         100MH          LS    S
  2.041  ELSEIF       @Bandwidth == 300E+6
  2.042  SCPI         TIM:SCAL 2ns
  2.043  9500         mVpp                         300MH          LS    S  L
  2.044  ELSE
  2.045  SCPI         TIM:SCAL 1ns
  2.046  9500         mVpp                         500MH          LS    S  L
  2.047  ENDIF

  2.048  WAIT         -t 5 System settling...
  2.049  SCPI         MEAS:VAMP?[I]
  2.050  MATH         MEM = MEM / 1E-3
# Compute 'dB down' from reference at UUT rated bandwidth and format.
  2.051  MATH         MEM2 = FMT((20 * LOG(MEM / L[1])), "%4.2f")
  2.052  MATH         MEM = MEM2
  2.053  MATH         S[32] = S[32] & MEM & " dB"
  2.054  EVAL   -e  ABS(MEM) < 3: Channel [V @Chan] @ [V Freq] MHz: [MEM] dB

  3.001  9500         *                                                 S
  3.002  SCPI         *RST
  3.003  HEAD
  3.004  HEAD         -2
  3.005  END

  3.006  EVAL   Increment step number


# Sub AT MSO/DSO60xx (1 yr) Horiz Delta t IEEE /9500 =========================

  4.001  LABEL        HORIZ_DELTA

  4.002  RSLT         =
  4.003  HEAD         {HORIZONTAL DELAY TIME ACCURACY}
  4.004  RSLT         =
  4.005  HEAD         -2 100 µs
  4.006  TARGET       -p
  4.007  SCPI         ACQ:MODE ETIME;TYPE AVERAGE;COUNT 8
  4.008  SCPI         DISP:VECT OFF
  4.009  SCPI         TRIG:MODE EDGE;SWE AUTO;EDGE:SOUR CHAN[V @Chan]
  4.010  SCPI         TRIG:COUP DC;LEV 0mV
  4.011  SCPI         MEAS:SOURCE CHAN[V @Chan]
  4.012  SCPI         CHAN[V @Chan]:SCAL 500mV;COUP DC

  4.013  IF           @Bandwidth == 100E+6
  4.014  9500         100.0uT                      1Vpp           M2    S
  4.015  ELSE
  4.016  SCPI         CHAN[V @Chan]:IMP FIFT
  4.017  9500         100.0uT                      1Vpp           M2    S  L
  4.018  ENDIF

  4.019  SCPI         TIM:SCAL 20us;REF LEFT
  4.020  WAIT         -t 5 System settling...
  4.021  TARGET       -m
  4.022  SCPI         MEAS:PER?[I]
  4.023  MATH         MEM = MEM * 1E+6
  4.024  MEMCX        uT             0.2U

  5.001  HEAD         -2 100 ns
  5.002  TARGET       -p

  5.003  IF           @Bandwidth == 100E+6
  5.004  9500         100.0nT                      1Vpp           M2    S
  5.005  ELSE
  5.006  9500         100.0nT                      1Vpp           M2    S  L
  5.007  ENDIF

  5.008  SCPI         TIM:SCAL 20ns
  5.009  WAIT         -t 5 System settling...
  5.010  TARGET       -m
  5.011  SCPI         MEAS:PER?[I]
  5.012  MATH         MEM = MEM * 1E+9
  5.013  MEMCX        nT             0.2U

  6.001  IF           @Bandwidth == 100E+6
  6.002  HEAD         -2 10 ns
  6.003  TARGET       -p
  6.004  9500         10.00nT                      1Vpp           M2    S

  6.005  SCPI         TIM:SCAL 5ns
  6.006  WAIT         -t 5 System settling...
  6.007  TARGET       -m
  6.008  SCPI         MEAS:PER?[I]
  6.009  MATH         MEM = MEM * 1E+9
  6.010  MEMCX        nT             0.07U

  7.001  ELSE

  7.002  HEAD         -2 5 ns
  7.003  TARGET       -p
  7.004  9500         5.00nT                       1Vpp           M4    S  L
  7.005  SCPI         TIM:SCAL 2ns
  7.006  WAIT         -t 5 System settling...
  7.007  TARGET       -m
  7.008  SCPI         MEAS:PER?[I]
  7.009  MATH         MEM = MEM * 1E+9
  7.010  MEMCX        nT             0.04U
  8.001  ENDIF

  8.002  HEAD         -2
  8.003  HEAD
  8.004  9500         *                                                 S
  8.005  SCPI         *RST
  8.006  END

  8.007  EVAL   Increment step number


# Sub AT MSO/DSO60xx (1 yr) Trig Sens IEEE /9500 =============================

  9.001  LABEL        TRIGGER

# Set the output of the calibrator so the peak-to-peak measurement is
# between 4 mV and 6 mV.  The minimum peak to peak output from the 9500
# is 4.4401 mVpp.  When this loop reaches that voltage it jumps out to the
# measurement routine.

# Due to qualitative nature of the test, repeated measurements unnecessary.
  9.002  VSET         NTHROW = 0; NMEAS = 1

  9.003  IF           @Chan == 1
  9.004  RSLT         =
  9.005  HEAD         {TRIGGER SENSITIVITY (Internal)}
  9.006  ELSE
  9.007  HEAD         TRIGGER SENSITIVITY (Internal)
  9.008  ENDIF

  9.009  RSLT         =
  9.010  HEAD         -2{Channel [V @Chan]}
  9.011  MATH         Bandwidth = @Bandwidth / 1E+6
  9.012  TARGET
  9.013  SCPI         CHAN[V @Chan]:SCAL 5mV;COUP DC
  9.014  SCPI         MEAS:SOURCE CHAN[V @Chan]
  9.015  SCPI         TRIG:MODE EDGE;SWE AUTO;EDGE:SOUR CHAN[V @Chan]
  9.016  SCPI         TIM:SCAL 10ns

  9.017  IF           @Bandwidth > 100E+6
  9.018  SCPI         CHAN[V @Chan]:IMP FIFT
  9.019  ENDIF

  9.020  MATH         MEM = 10; M[1] = MEM

  9.021  DO
  9.022  MATH         M[1] = M[1] - 1; MEM = M[1]

  9.023  IF           @Bandwidth == 100E+6
  9.024  9500         mVpp                         25MH           LS    S
  9.025  ELSE
  9.026  9500         mVpp                         25MH           LS    S  L
  9.027  ENDIF

  9.028  SCPI         MEAS:VAMP?[I]
  9.029  MATH         MEM = MEM / 1E-3
  9.030  UNTIL        ((MEM > 4) && (MEM <= 6))|| M[1] == 4.4401

  9.031  SCPI         TRIG:SWE NORM
  9.032  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
  9.033  SCPI         TRIG:SWE AUTO
  9.034  EVAL   -e  @Trig :[32]1.0 div. @ 25 MHz

 10.001  SCPI         CHAN[V @Chan]:SCAL 100mV

 10.002  IF           @Bandwidth == 100E+6
 10.003  SCPI         TIM:SCAL 5ns
 10.004  ELSEIF       @Bandwidth == 300E+6
 10.005  SCPI         TIM:SCAL 2ns
 10.006  ELSE
 10.007  SCPI         TIM:SCAL 1ns
 10.008  ENDIF

 10.009  MATH         MEM = 60; MEM1 = MEM

 10.010  DO
 10.011  MATH         MEM = MEM1 + (60 - MEM) / 2

 10.012  IF           @Bandwidth == 100E+6
 10.013  9500         mVpp                         100MH          LS    S
 10.014  ELSEIF       @Bandwidth == 300E+6
 10.015  9500         mVpp                         300MH          LS    S  L
 10.016  ELSEIF       @Bandwidth == 500E+6
 10.017  9500         mVpp                         500MH          LS    S  L
 10.018  ELSE
 10.019  DISP         ERROR: Unsupported bandwidth [V Bandwidth] MHz
 10.020  ENDIF

 10.021  SCPI         MEAS:VAMP?[I]
 10.022  MATH         MEM = MEM / 1E-3
 10.023  UNTIL        (MEM >= 58) && (MEM <= 62)

 10.024  SCPI         TRIG:SWE NORM
 10.025  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
 10.026  SCPI         TRIG:SWE AUTO
 10.027  EVAL   -e  @Trig :[32]0.6 div. @ [V Bandwidth] MHz

 11.001  9500         *                                                 S
 11.002  SCPI         *RST
 11.003  VSET         NTHROW = [V @NThrow]; NMEAS = [V @NMeas]
 11.004  HEAD         -2
 11.005  HEAD
 11.006  END

 11.007  EVAL   Increment step number


# Sub AT MSO/DSO60xx (1 yr) Ext Trig 2Ch IEEE /9500 ==========================
#
# This test is optional because External Trigger Sensitivity is a
# characteristic, not a specification.  This test applies to 2-channel models
# only.

 12.001  LABEL        EXT_TRIG_2CH

# Due to qualitative nature of the test, repeated measurements unnecessary.
 12.002  VSET         NTHROW = 0; NMEAS = 1

 12.003  RSLT         =
 12.004  HEAD         {TRIGGER SENSITIVITY (External)}
 12.005  RSLT         =
 12.006  HEAD         TRIGGER SENSITIVITY (External): {±1 V Range}
 12.007  MATH         Bandwidth = @Bandwidth / 1E+6
 12.008  TARGET
 12.009  HEAD         -2 25 MHz
 12.010  SCPI         CHAN[V @Chan]:SCAL 20mV
 12.011  SCPI         MEAS:SOURCE CHAN[V @Chan]
 12.012  SCPI         TIM:SCAL 10ns
 12.013  SCPI         TRIG:MODE EDGE;SWE AUTO;EDGE:SOUR EXT
 12.014  SCPI         EXT:RANG 1V

 12.015  IF           @Bandwidth > 100E+6
 12.016  SCPI         CHAN[V @Chan]:IMP FIFT;:EXT:IMP FIFT
 12.017  ENDIF

 12.018  TARGET       -m
 12.019  MATH         MEM = 100; MEM1 = MEM

 12.020  DO
 12.021  MATH         MEM = MEM1 + (100 - MEM) / 2

 12.022  IF           @Bandwidth == 100E+6
 12.023  9500         mVpp                         25MH           LS    S
 12.024  ELSE
 12.025  9500         mVpp                         25MH           LS    S  L
 12.026  ENDIF

 12.027  SCPI         MEAS:VAMP?[I]
 12.028  MATH         MEM = MEM / 1E-3
 12.029  UNTIL        (MEM >= 95) && (MEM < 100)

 12.030  SCPI         TRIG:SWE NORM
 12.031  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
 12.032  SCPI         TRIG:SWE AUTO
 12.033  EVAL   -e  @Trig :[32]100 mV @ 25 MHz


 13.001  HEAD         -2 [V Bandwidth] MHz
 13.002  SCPI         CHAN[V @Chan]:SCAL 50mV

 13.003  IF           @Bandwidth == 100E+6
 13.004  SCPI         TIM:SCAL 5ns
 13.005  ELSEIF       @Bandwidth == 300E+6
 13.006  SCPI         TIM:SCAL 2ns
 13.007  ELSEIF       @Bandwidth == 500E+6
 13.008  SCPI         TIM:SCAL 1ns
 13.009  ELSE
 13.010  DISP         {TRIGGER SENSITIVITY (External): ±1 V Range}
 13.010  DISP
 13.010  DISP         {ERROR: Unsupported bandwidth @ [V Bandwidth] MHz}
 13.011  END
 13.012  ENDIF

 13.013  TARGET       -m
 13.014  MATH         MEM = 200; MEM1 = MEM

 13.015  DO
 13.016  MATH         MEM = MEM1 + (200 - MEM) / 2

 13.017  IF           @Bandwidth == 100E+6
 13.018  9500         mVpp                         100MH          LS    S
 13.019  ELSEIF       @Bandwidth == 300E+6
 13.020  9500         mVpp                         300MH          LS    S  L
 13.021  ELSEIF       @Bandwidth == 500E+6
 13.022  9500         mVpp                         500MH          LS    S  L
 13.023  ENDIF

 13.024  SCPI         MEAS:VAMP?[I]
 13.025  MATH         MEM = MEM / 1E-3
 13.026  UNTIL        (MEM >= 195) && (MEM < 200)

 13.027  SCPI         TRIG:SWE NORM
 13.028  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
 13.029  SCPI         TRIG:SWE AUTO
 13.030  EVAL   -e  @Trig :[32]200 mV @ [V Bandwidth] MHz


 14.001  RSLT         =
 14.002  HEAD         TRIGGER SENSITIVITY (External): {±8 V Range}
 14.003  TARGET
 14.004  HEAD         -2 25 MHz
 14.005  SCPI         CHAN[V @Chan]:SCAL 50mV
 14.006  SCPI         TIM:SCAL 10ns
 14.007  SCPI         EXT:RANG 8V

 14.008  TARGET       -m
 14.009  MATH         MEM = 250; MEM1 = MEM

 14.010  DO
 14.011  MATH         MEM = MEM1 + (250 - MEM) / 2

 14.012  IF           @Bandwidth == 100E+6
 14.013  9500         mVpp                         25MH           LS    S
 14.014  ELSE
 14.015  9500         mVpp                         25MH           LS    S  L
 14.016  ENDIF

 14.017  SCPI         MEAS:VAMP?[I]
 14.018  MATH         MEM = MEM / 1E-3
 14.019  UNTIL        (MEM >= 245) && (MEM < 250)

 14.020  SCPI         TRIG:SWE NORM
 14.021  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
 14.022  SCPI         TRIG:SWE AUTO
 14.023  EVAL   -e  @Trig :[32]250 mV @ 25 MHz

 15.001  HEAD         -2 [V Bandwidth] MHz

 15.002  SCPI         CHAN[V @Chan]:SCAL 100mV

 15.003  IF           @Bandwidth == 100E+6
 15.004  SCPI         TIM:SCAL 5ns
 15.005  ELSEIF       @Bandwidth == 300E+6
 15.006  SCPI         TIM:SCAL 2ns
 15.007  ELSEIF       @Bandwidth == 500E+6
 15.008  SCPI         TIM:SCAL 1ns
 15.009  ENDIF

 15.010  TARGET       -m
 15.011  MATH         MEM = 500; MEM1 = MEM

 15.012  DO
 15.013  MATH         MEM = MEM1 + (500 - MEM) / 2

 15.014  IF           @Bandwidth == 100E+6
 15.015  9500         mVpp                         100MH          LS    S
 15.016  ELSEIF       @Bandwidth == 300E+6
 15.017  9500         mVpp                         300MH          LS    S  L
 15.018  ELSEIF       @Bandwidth == 500E+6
 15.019  9500         mVpp                         500MH          LS    S  L
 15.020  ENDIF

 15.021  SCPI         MEAS:VAMP?[I]
 15.022  MATH         MEM = MEM / 1E-3
 15.023  UNTIL        (MEM >= 495) && (MEM < 500)

 15.024  SCPI         TRIG:SWE NORM
 15.025  CALL         Sub AT MSO/DSO6xxx Wait for Triggered
 15.026  SCPI         TRIG:SWE AUTO
 15.027  EVAL   -e  @Trig :[32]500 mV @ [V Bandwidth] MHz

 16.001  9500         *                                                 S
 16.002  SCPI         *RST
 16.003  VSET         NTHROW = [V @NThrow]; NMEAS = [V @NMeas]
 16.004  HEAD         -2
 16.005  HEAD
 16.006  END

 16.007  EVAL   Increment Step Number


# Sub AT MSO/DSO60xx (1 yr) Time Scale IEEE /9500 ============================

 17.001  LABEL        TIME_SCALE

# Due to qualitative nature of the test, repeated measurements unnecessary.
 17.002  VSET         NTHROW = 0; NMEAS = 1

 17.003  RSLT         =
 17.004  HEAD         {TIME SCALE ACCURACY}
 17.005  RSLT         =
 17.006  TARGET
 17.007  SCPI         TRIG:MODE EDGE;SWE AUTO;:TIM:SCAL 5ns
 17.008  SCPI         ACQ:MODE ETIME;TYPE AVERAGE;COUNT 65536
 17.009  SCPI         MARK:MODE WAV
 17.010  SCPI         CHAN[V @Chan]:SCAL 200mV;COUP DC

 17.011  IF           @Bandwidth > 100E+6
 17.012  SCPI         CHAN[V @Chan]:IMP FIFT
 17.013  ENDIF

 17.014  TARGET       -p
 17.015  HEAD         -2 Horizontal Position: 0 ms
 17.016  MATH         Xpos = 0
 17.017  SCPI         TIM:POS [V Xpos]s;:SINGLE
 17.018  SCPI         MARK:X1P [V Xpos]s;X2P [V Xpos]s

 17.019  IF           @Bandwidth == 100E+6
 17.020  9500         10MH                         1Vpp           LS    S
 17.021  ELSE
 17.022  9500         10MH                         1Vpp           LS    S  L
 17.023  ENDIF

 17.024  SCPI         RUN
 17.025  WAIT         -t 5 Acquiring averages, please wait...
 17.026  SCPI         MARK:Y1P?[I]

# Adjust the X1 marker until it reaches the center graticule (+/- 2 mV).
 17.027  DO
 17.028  MATH         Xstep = MEM / 100E+6 ; Xpos = Xpos - Xstep
 17.029  SCPI         MARK:X1P [V Xpos]s;[D100]:MARK:Y1P?[I]
 17.030  UNTIL        ABS(MEM) < 2E-3

 17.031  SCPI         MARK:X1P?[I];:MARK:MODE OFF
# Store X1 marker position.
 17.032  MATH         X1 = MEM

 17.033  HEAD         -2 Horizontal Position: 1 ms
 17.034  MATH         Xpos = 1E-3
 17.035  SCPI         TIM:POS +[V Xpos]s;:SINGLE

 17.036  IF           @Bandwidth == 100E+6
 17.037  9500         10MH                         1Vpp           LS    S
 17.038  ELSE
 17.039  9500         10MH                         1Vpp           LS    S  L
 17.040  ENDIF

# Retrieve frequency accuracy and convert to ppm.
 17.041  MATH         FreqAcc = REFACC(); L[1] = FreqAcc / 10
 17.042  ACC          0.00ppm        L1U
 17.043  SCPI         RUN
 17.044  WAIT         -t 20 Acquiring averages, please wait...
 17.045  SCPI         MARK:MODE WAV;X1P [V Xpos]s;X2P [V Xpos]s
 17.046  SCPI         [D100]MARK:Y1P?[I]

 17.047  DO
 17.048  MATH         Xstep = MEM / 100E+6 ; Xpos = Xpos - Xstep
 17.049  SCPI         MARK:X1P [V Xpos]s;[D100]:MARK:Y1P?[I]
 17.050  UNTIL        ABS(MEM) < 2E-3

 17.051  SCPI         MARK:X1P?[I]
 17.052  MATH         X2 = MEM

# Calculate Delta between cursors and convert to ppm.
 17.053  MATH         MEM = ((X2 - 0.001) - X1) / 1E-9
 17.054  MATH         L[1] = @TimeScaleLimit
 17.055  MEMCX        0.00ppm        L1U


 18.001  9500         *                                                 S
 18.002  SCPI         *RST
 18.003  VSET         NTHROW = [V @NThrow]; NMEAS = [V @NMeas]
 18.004  HEAD
 18.005  HEAD         -2
 18.006  END

